// Generated by CoffeeScript 1.4.0
(function() {
  var __hasProp = {}.hasOwnProperty,
    __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

  window.Controls.bind__template = (function(_super) {

    __extends(bind__template, _super);

    function bind__template() {
      return bind__template.__super__.constructor.apply(this, arguments);
    }

    bind__template.prototype.append = function(child) {
      this.dom = child.dom;
      if (!this.properties.visible && this.dom) {
        $(this.dom).hide();
      }
      this.properties = child.properties;
      return this.children.push(child);
    };

    return bind__template;

  })(window.Control);

}).call(this);
