(function(){var b=function(d,e){return function(){return d.apply(e,arguments)}},a={}.hasOwnProperty,c=function(g,e){for(var d in e){if(a.call(e,d)){g[d]=e[d]}}function f(){this.constructor=g}f.prototype=e.prototype;g.prototype=new f();g.__super__=e.prototype;return g};window.Controls.logs__log=(function(e){c(d,e);function d(){this.add=b(this.add,this);return d.__super__.constructor.apply(this,arguments)}d.prototype.createDom=function(){this.dom=$('<textarea class="control textbox log">\n</textarea>');if(this.properties.path){this.socket=ajentiConnectSocket("/log");this.socket.send(JSON.stringify({type:"select",path:this.properties.path}));return this.socket.on("add",this.add)}};d.prototype.add=function(f){$(this.dom).val($(this.dom).val()+f);return this.dom.scrollTop=this.dom.scrollHeight};d.prototype.onBroadcast=function(f){if(f==="destruct"){if(this.socket){return this.socket.disconnect()}}};return d})(window.Control)}).call(this);