(function(){var a={}.hasOwnProperty,b=function(f,d){for(var c in d){if(a.call(d,c)){f[c]=d[c]}}function e(){this.constructor=f}e.prototype=d.prototype;f.prototype=new e();f.__super__=d.prototype;return f};window.Controls.main__page=(function(c){b(d,c);function d(){return d.__super__.constructor.apply(this,arguments)}d.prototype.createDom=function(){var e=this;this.dom=$('<div class="control container main-page"> \n    <div class="content-wr">\n        <div class="feedback">\n            <a class="activate">Leave Feedback</a>\n            <div class="box">\n                <label>Email (optional)</label>\n                <br/>\n                <input class="control textbox" />\n                <br/>\n                <label>Text</label>\n                <br/>\n                <textarea class="control textbox"></textarea>\n                <br/>\n                <a href="#" class="control button style-normal">Submit</a>\n            </div>\n        </div>\n\n        <div class="content">\n            <div class="--child-container"></div>\n        </div>\n    </div>\n</div>');this.childContainer=this.dom.find(".--child-container");this.feedback=this.dom.find(".feedback");this.feedback.find(".box").hide();this.feedback.find(".activate").click(function(){return e.feedback.find(".box").toggle()});return this.feedback.find(".box a").click(function(){e.feedback.find(".box").hide();return e.event("feedback",{email:e.feedback.find("input").val(),text:e.feedback.find("textarea").val()})})};return d})(window.Control);window.Controls.main__sections_tab=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){return this.dom=$('<a href="#" class="tab '+(this.properties.active?"active":"")+'">\n    <i class="icon-'+this.properties.icon+'"></i>&nbsp;'+this.properties.title+"\n</a>")};return c})(window.Control);window.Controls.main__sections_category=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){this.dom=$('<div class="control container main-sections-category"> \n    <div>'+this.properties.name+'</div>\n    <div class="content">\n        <div class="--child-container"></div>\n    </div>\n</div>');return this.childContainer=this.dom.find(".--child-container")};return c})(window.Control);window.Controls.main__sections_root=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){this.dom=$('<div class="control container main-sections-root">\n    <div class="sidebar">\n        <div class="--tabs-container"></div>\n    </div>\n    <div class="main">\n        <div class="--child-container"></div>\n    </div>\n</div>');this.tabsContainer=this.dom.find(".--tabs-container");this.childContainer=this.dom.find(".--child-container");return this.categories={}};c.prototype.append=function(h){var e,f,g=this;if(!this.categories[h.properties.category]){e=new Controls.main__sections_category(this.ui,{name:h.properties.category});this.categories[h.properties.category]=e;this.tabsContainer.append(e.dom)}f=new Controls.main__sections_tab(this.ui,$.extend(h.properties,{visible:true}));$(f.dom).click(function(i){g.event("switch",{uid:h.uid});return i.preventDefault()});this.categories[h.properties.category].append(f);return c.__super__.append.call(this,h)};return c})(window.Control);window.Controls.main__section=(function(c){b(d,c);function d(){return d.__super__.constructor.apply(this,arguments)}d.prototype.createDom=function(){this.dom=$('<div class="control container section '+(this.properties.active?"active":"")+" "+(this.properties.plain?"plain":"normal")+'"">\n    <div class="--child-container"></div>\n</div>');return this.childContainer=this.dom.find(".--child-container")};return d})(window.Control);window.Controls.body=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){this.dom=$('<div class="control container section-body">\n</div>');return this.childContainer=this.dom};return c})(window.Control)}).call(this);